
**********************************************************************************
* US Forecasts of Consumption, Carroll and Slacalek, 2009
**********************************************************************************

clear
#delimit;
version 9.0;
set scheme s1mono; *s2color;

set more off;
global basePath "C:\Jirka\Research\usForeC\ReformingOrResting";
global dataPath $basePath\data;  
global logPath $basePath\Software\stata;
global docPath $basePath\Figures;

cd $logPath;
capture log close;
log using $logPath\reformingOrResting_graphs.log, replace;

global consIndex "1";		* 1: total PCE [default], 2: total PCE ex housing services, 3: NDS;
global startReg "1960q1";	* start of the sample;
global endReg "2008q4";		* end of the sample;
global startRegW "1960q1";	* start of the sample for wealth regressions "1985q1";
global endRegW "2008q4";		* end of the estimation sample for wealth regressions;
global startFore "2009q1";	* start of the sample for wealth regressions "1985q1";
global endFore "2012q4";		* end of the estimation sample for wealth; 
global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;

global nwLags "4";			* # of lags for Newey-West std errors;
global nwLagsW "8";			* # of lags for Newey-West std errors in wealth regressions;

global controlVars "L.MUExp L.fedfunds";
*global controlVars "L.MUExp L.fedfunds L.cHouseDel"; * uncomment with consIndex "2" if controlling for housing services;
global ivsetW "L(2).dwdel";
global ivsetWPlus "L(2).dwdel L(2).MUExp L(2).fedfunds";
global ivsetWSandN "L(2).dwstdel L(2).dwnstdel";
global ivsetWSandNPlus "L(2).dwstdel L(2).dwnstdel L(2).MUExp L(2).fedfunds";
global normVar "tcons";		* tcons ydisp;

log off;
use $dataPath\usdata09.dta;
gen t =  q(1947q1)+_n-1;
format t %tq;
tsset t;

do transformData;
log on;

cd $basePath\figures;
set scheme s1mono;

* Net Worth;
**********************************************************************************;

gen netWorthOverDispInc=networth/disposy;
gen tanAssetsOverDispInc=tanasset/disposy;
gen finAssetsOverDispInc=finasset/disposy;
gen liabOverDispInc=-liability/disposy;

graph twoway
(line netWorthOverDispInc t if tin(1952Q1,2008Q4), clwidth(medthick) lcolor(black))
(line tanAssetsOverDispInc t if tin(1952Q1,2008Q4), clwidth(medthin) lcolor(black) lpattern(dash))
(line finAssetsOverDispInc t if tin(1952Q1,2008Q4), clwidth(medthin) lcolor(black) lpattern(dash_dot))
(line liabOverDispInc t if tin(1952Q1,2008Q4), clwidth(medthin) lcolor(black) xtitle("") xlabel(-20(20)180,format(%tqCY)) yline(0)),
legend(lab(1 "Net Worth") lab(2 "Tangible Assets") lab(3 "Financial Assets") lab(4 "Liabilities")) name(usNetWorth);

graph save usNetWorth usNetWorth, asis replace;
graph export usNetWorth.eps, replace;
* graph export usNetWorth.png, replace width(800) height(600);

* Net Borrowing;
**********************************************************************************;

gen netBorrowingOverDispInc=100*borrbyhh/(disposy*1000);

graph twoway (line netBorrowingOverDispInc t if tin(1952Q1,2008Q4), clwidth(medthick) lcolor(black) xtitle("") ytitle("") xlabel(-20(20)180,format(%tqCY)) yline(0)), legend(off) name(usNetBorrowing);

graph save usNetBorrowing usNetBorrowing, asis replace;
graph export usNetBorrowing.eps, replace;
* graph export usNetBorrowing.png, replace width(800) height(600);

* U Expectations;
**********************************************************************************;

gen deltaUexp=icsq_12-L4.icsq_12;
gen uExp=icsq_12;
gen persSavingRate=100*persave/disposy;
label var deltaUexp "Michigan Unemployment Expectations";
label var persSavingRate "Personal Saving Rate (Percent)";

graph twoway (line uExp t if tin(1960Q1,2008Q4), clwidth(medthick) lcolor(black) xtitle("") xlabel(0(20)180,format(%tqCY)) yline(0) legend(off) ytitle("") name(uExpHistory));

graph save uExpHistory uExpHistory, asis replace;
graph export uExpHistory.eps, replace;
* graph export uExpHistory.png, replace width(800) height(600);

**********************************************************************************;
drop _all;

* Retail Sales;
**********************************************************************************;
use $dataPath\retailSales_allRecs.dta;
gen monthInRecession=month-1;
gen oneHundred=100;

graph twoway 
(area maxrs monthInRecession , color(gs11))
(area minrs monthInRecession , color(white))
(line meanrs monthInRecession, clwidth(medthin) lcolor(black) lpattern(dash) xtitle("Months after Start of Recession") xlabel(0(6)36))
(line oneHundred monthInRecession, clwidth(thin) lcolor(black))
(line currentrs monthInRecession, clwidth(medthick) lcolor(black)), legend(cols(3) order(1 3 5) lab(1 "Historical Range") lab(3 "Historical Mean") lab(5 "Current Recession") size(small)) name(retailSales);

graph save retailSales retailSales, asis replace;
graph export retailSales.eps, replace;
* graph export retailSales.png, replace width(800) height(600);

**********************************************************************************;
drop _all;

* Credit Conditions;
**********************************************************************************;
use $dataPath\sloCreditConditions.dta;
gen t =  q(1990q1)+_n-1;
format t %tq;
tsset t;

graph twoway 
(line mortgages_all t, clwidth(medthick) lcolor(black))
(line mortgages_prime t, clwidth(medthick) lcolor(red))
(line mortgages_nontraditional t, clwidth(medthin) lcolor(black) lpattern(dash))
(line mortgages_subprime t, clwidth(medthin) lcolor(black) xtitle("") xlabel(120(20)180,format(%tqCY)) yline(0) yscale(range(-20 100))  ylabel(-20 0 50 100)),
legend(lab(1 "Mortgages (All)") lab(2 "Mortgages (Prime)") lab(3 "Mortgages (Nontraditional)") lab(4 "Mortgages (Subprime)")) name(creditConditions);

graph save creditConditions creditConditions, asis replace;
graph export creditConditions.eps, replace;
* gr export creditConditions.png, replace width(800) height(600);


**********************************************************************************;

cd $logPath;
**********************************************************************************;
log close;	
