
**********************************************************************************
* US Forecasts of Consumption, Carroll and Slacalek, 2009
**********************************************************************************

clear
#delimit;
version 9.0;
set scheme s1mono; *s2color s1mono;

set more off;
global basePath "C:\Jirka\Research\usForeC\ParadoxBigTime";
global dataPath $basePath\data;  
global logPath $basePath\Software\stata;
global docPath $basePath\Figures;

cd $logPath;
capture log close;
log using $logPath\usForeCmain_2.log, replace;

global consIndex "1";		* 1: total PCE [default], 2: total PCE ex housing services, 3: NDS;
global startReg "1960q1";	* start of the sample;
global endReg "2008q4";		* end of the sample;
global startRegW "1960q1";	* start of the sample for wealth regressions "1985q1";
global endRegW "2008q4";		* end of the estimation sample for wealth regressions;
global startFore "2009q2";	* start of the sample for wealth regressions "1985q1";
global startForeM1 "2009q1";	* one quarter before startFore;
global endFore "2012q4";		* end of the estimation sample for wealth; 
global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;

global sentScenario "2";	* pick counterfactual for sentiment: 1 constant (default), 2  epidemiology through Un;
global cfIncomeIndex "1";	* 1: Consensus Forecasts expectations of income (default), 2 stress test, scenario-specific income expectations;
global fixSentIndex "1";	* 1: Sentiment varies across scenarios (default), 2: sentiment constant across scenarios;
global imposeCOSestIndex "2";	* 1: imposes COS estimates of the wealth effect;

global nwLags "4";			* # of lags for Newey-West std errors;
global nwLagsW "8";			* # of lags for Newey-West std errors in wealth regressions;

global controlVars "L.MUExp L.fedfunds";
*global controlVars "L.MUExp L.fedfunds L.cHouseDel"; * uncomment with consIndex "2" if controlling for housing services;
global ivsetW "L(2).dwdel";
global ivsetWPlus "L(2).dwdel L(2).MUExp L(2).fedfunds";
global ivsetWSandN "L(2).dwstdel L(2).dwnstdel";
global ivsetWSandNPlus "L(2).dwstdel L(2).dwnstdel L(2).MUExp L(2).fedfunds";
global normVar "tcons";		* tcons ydisp;

log off;
use $dataPath\usdata09.dta;
gen t =  q(1947q1)+_n-1;
format t %tq;
tsset t;

global startForeNum = q($startFore)-q(1947q1)+1;
global endForeNum = q($endFore)-q(1947q1)+1;

do transformData;
log on;

**********************************************************************************;
* W Only;
ivreg2 cdel (L.cdel = $ivsetW) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decay = _b[L.cdel];
sca seDecay = _se[L.cdel];
gen dwdel4Geom  = (D.wealth+decay*LD.wealth +(decay^2)*L2D.wealth +(decay^3)*L3D.wealth)/L4.$normVar;

gen cw1 = LD.wealth/L4.$normVar;
gen cw2 = decay*L2D.wealth/L4.$normVar;
gen cw3 = (decay^2)*L3D.wealth/L4.$normVar;
gen cw4 = (decay^3)*L4D.wealth/L4.$normVar;

* testing the restrictions in dwsdel4GeomSNPlus and dwndel4GeomSNPlus  ;
newey cdel cw1-cw4  if tin($startReg,$endReg), lag($nwLags);	* HAC errors;
test cw1 = cw2 = cw3 = cw4;

reg cdel L.dwdel4Geom if tin($startRegW,$endRegW);
sca rbarW1 = e(r2_a);
newey cdel L.dwdel4Geom if tin($startRegW,$endRegW), lag($nwLagsW);
sca bW1 = _b[L.dwdel4Geom];
sca seW1 = _se[L.dwdel4Geom];

durbina ,lag(8) force robust;
sca LRIVW = bW1/(decay*(1-decay));
disp LRIVW;

* W Plus;
**********************************************************************************;
ivreg2 cdel (L.cdel = $ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decayPlus = _b[L.cdel];
sca seDecayPlus = _se[L.cdel];
gen dwdel4GeomPlus  = (D.wealth+decayPlus*LD.wealth +(decayPlus^2)*L2D.wealth +(decayPlus^3)*L3D.wealth)/L4.$normVar;

cap drop cw1-cw4;
gen cw1 = LD.wealth/L4.$normVar;
gen cw2 = decayPlus*L2D.wealth/L4.$normVar;
gen cw3 = (decayPlus^2)*L3D.wealth/L4.$normVar;
gen cw4 = (decayPlus^3)*L4D.wealth/L4.$normVar;

* testing the restrictions in dwsdel4GeomSNPlus and dwndel4GeomSNPlus  ;
newey    cdel cw1-cw4  if tin($startReg,$endReg), lag($nwLags);	* HAC errors;
test cw1 = cw2 = cw3 = cw4;

reg cdel L.dwdel4GeomPlus $controlVars if tin($startRegW,$endRegW);
sca rbarWPlus = e(r2_a);

newey cdel L.dwdel4GeomPlus $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca bWPlus1 = _b[L.dwdel4GeomPlus];
sca seWPlus1 = _se[L.dwdel4GeomPlus];
sca bWPlus2 = _b[L.MUExp];
sca seWPlus2 = _se[L.MUExp];
sca bWPlus3 = _b[L.fedfunds];
sca seWPlus3 = _se[L.fedfunds];

sca bdwdel4GeomPlus = _b[L.dwdel4GeomPlus];
sca sedwdel4GeomPlus = _se[L.dwdel4GeomPlus];
sca bWPlusMich = _b[L.MUExp];
sca seWPlusMich = _se[L.MUExp];
sca bWPlusFF = _b[L.fedfunds];
sca seWPlusFF = _se[L.fedfunds];
sca bWPlusConst = _b[_cons];

durbina ,lag(8) force robust;
sca LRIVWPlus = bWPlus1/(decayPlus*(1-decayPlus));
disp LRIVWPlus;

* WSAndWN;
**********************************************************************************;
ivreg2 cdel (L.cdel = $ivsetWSandN) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decaySandN = _b[L.cdel];
sca seDecaySandN = _se[L.cdel];

gen dwstdel4GeomSN  = (D.wthstock+decaySandN*LD.wthstock +(decaySandN^2)*L2D.wthstock +(decaySandN^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdel4GeomSN  = (D.wthnonstock+decaySandN*LD.wthnonstock +(decaySandN^2)*L2D.wthnonstock + (decaySandN^3)*L3D.wthnonstock)/L4.$normVar;

gen cwst1 = LD.wthstock/L4.$normVar;
gen cwst2 = decaySandN*L2D.wthstock/L4.$normVar;
gen cwst3 = (decaySandN^2)*L3D.wthstock/L4.$normVar;
gen cwst4 = (decaySandN^3)*L4D.wthstock/L4.$normVar;

gen cwnst1 = LD.wthnonstock/L4.$normVar; 
gen cwnst2 = decaySandN*L2D.wthnonstock/L4.$normVar;
gen cwnst3 = (decaySandN^2)*L3D.wthnonstock/L4.$normVar;
gen cwnst4 = (decaySandN^3)*L4D.wthnonstock/L4.$normVar;

* testing the restrictions in dwstdel4GeomSNSandN and dwnstdel4GeomSNSandN  ;
newey    cdel cwst1-cwst4 cwnst1-cwnst4  if tin($startRegW,$endRegW), lag($nwLags);	* HAC errors;
test cwst1 = cwst2 = cwst3 = cwst4;
test cwnst1 = cwnst2 = cwnst3 = cwnst4;

reg cdel L.dwstdel4GeomSN L.dwnstdel4GeomSN if tin($startRegW,$endRegW); 
sca rbarWSN = e(r2_a);

newey cdel L.dwstdel4GeomSN L.dwnstdel4GeomSN if tin($startRegW,$endRegW), lag($nwLagsW);
sca bdwstdel4GeomSN = _b[L.dwstdel4GeomSN];
sca sedwstdel4GeomSN = _se[L.dwstdel4GeomSN];
sca bdwnstdel4GeomSN = _b[L.dwnstdel4GeomSN];
sca sedwnstdel4GeomSN = _se[L.dwnstdel4GeomSN];

test L.dwstdel4GeomSN = L.dwnstdel4GeomSN;
sca pvalSN = r(p);
disp pvalSN;

durbina ,lag(8) force robust;
scalar  LRIVST = bdwstdel4GeomSN/(decaySandN*(1-decaySandN));
scalar  LRIVNST = bdwnstdel4GeomSN/(decaySandN*(1-decaySandN));
disp LRIVST;
disp LRIVNST;

* WSAndWNPlus;
**********************************************************************************;
ivreg2 cdel (L.cdel = $ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca decaySandNPlus = _b[L.cdel];
sca seDecaySandNPlus = _se[L.cdel];

gen dwstdel4GeomSNPlus  = (D.wthstock+decaySandNPlus*LD.wthstock +(decaySandNPlus^2)*L2D.wthstock +(decaySandNPlus^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdel4GeomSNPlus  = (D.wthnonstock+decaySandNPlus*LD.wthnonstock +(decaySandNPlus^2)*L2D.wthnonstock + (decaySandNPlus^3)*L3D.wthnonstock)/L4.$normVar;

cap drop cwnst1-cwnst4 cwst1-cwst4;

gen cwst1 = LD.wthstock/L4.$normVar;
gen cwst2 = decaySandNPlus*L2D.wthstock/L4.$normVar;
gen cwst3 = (decaySandNPlus^2)*L3D.wthstock/L4.$normVar; 
gen cwst4 = (decaySandNPlus^3)*L4D.wthstock/L4.$normVar;

gen cwnst1 = LD.wthnonstock/L4.$normVar; 
gen cwnst2 = decaySandNPlus*L2D.wthnonstock; 
gen cwnst3 = (decaySandNPlus^2)*L3D.wthnonstock; 
gen cwnst4 = (decaySandNPlus^3)*L4D.wthnonstock; 

* testing the restrictions in dwstdel4GeomSNSandNPlus and dwnstdel4GeomSNSandNPlus  ;
newey cdel cwst1-cwst4 cwnst1-cwnst4  if tin($startRegW,$endRegW), lag($nwLags);	* HAC errors;
test cwst1 = cwst2 = cwst3 = cwst4;
test cwnst1 = cwnst2 = cwnst3 = cwnst4;

reg cdel L.dwstdel4GeomSNPlus L.dwnstdel4GeomSNPlus $controlVars if tin($startRegW,$endRegW);
sca rbarWSNPlus = e(r2_a);

newey cdel L.dwstdel4GeomSNPlus L.dwnstdel4GeomSNPlus $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca bdwstdel4GeomSNPlus = _b[L.dwstdel4GeomSNPlus];
sca sedwstdel4GeomSNPlus = _se[L.dwstdel4GeomSNPlus];
sca bdwnstdel4GeomSNPlus = _b[L.dwnstdel4GeomSNPlus];
sca sedwnstdel4GeomSNPlus = _se[L.dwnstdel4GeomSNPlus];
sca bSNPlusMich = _b[L.MUExp];
sca seSNPlusMich = _se[L.MUExp];
sca bSNPlusFF = _b[L.fedfunds];
sca seSNPlusFF = _se[L.fedfunds];
sca bSNPlusConst = _b[_cons];

predict cdelPredSNPlus;

test L.dwstdel4GeomSNPlus = L.dwnstdel4GeomSNPlus;
sca pvalSNPlus = r(p);
disp pvalSNPlus;

durbina ,lag(8) force robust;
scalar  LRIVSTPlus = bdwstdel4GeomSNPlus/(decaySandNPlus*(1-decaySandNPlus));
scalar  LRIVNSTPlus = bdwnstdel4GeomSNPlus/(decaySandNPlus*(1-decaySandNPlus));
disp LRIVSTPlus;
disp LRIVNSTPlus;

if $imposeCOSestIndex==1 {; 
	sca decay=.575767; 
	sca decayPlus=.7616193;
	sca decaySandN=.4538004;
	sca decaySandNPlus=.7113552 ; 

	sca bdwdel4GeomPlus = .0086995;
	sca bWPlusMich = .0859004;
	sca bWPlusFF = -.3990706;
	sca bWPlusConst = .000474;

	sca bdwstdel4GeomSNPlus = .0084074;
	sca bdwnstdel4GeomSNPlus = .0177889;
	sca bSNPlusMich = .0821333;
	sca bSNPlusFF = -.4112476;
	sca bSNPlusConst = .000389;
};


log off;

* Tables;
**********************************************************************************;
mat tableSR = (
bW1,.,.,.,.,.,rbarW1\
seW1,.,.,.,.,.,.\
bWPlus1,.,.,bWPlus2,bWPlus3,.,rbarWPlus\
seWPlus1,.,.,seWPlus2,seWPlus3,.,.\
.,bdwstdel4GeomSN,bdwnstdel4GeomSN,.,.,pvalSN,rbarWSN\
.,sedwstdel4GeomSN,sedwnstdel4GeomSN,.,.,.,.\
.,bdwstdel4GeomSNPlus,bdwnstdel4GeomSNPlus,bSNPlusMich,bSNPlusFF,pvalSNPlus,rbarWSNPlus\
.,sedwstdel4GeomSNPlus,sedwnstdel4GeomSNPlus,seSNPlusMich,seSNPlusFF,.,.
);

mat colnames tableSR = dW dWS dWN MU FF Test barR2;
mat rownames tableSR = W - Wplus - WNS - WNSplus -;

mat tableLR = (
decay,LRIVW,.,.\
seDecay,.,.,.\
decayPlus,LRIVWPlus,.,.\
seDecayPlus,.,.,.\
decaySandN,.,LRIVST,LRIVNST\
seDecaySandN,.,.,.\
decaySandNPlus,.,LRIVSTPlus,LRIVNSTPlus\
seDecaySandNPlus,.,.,.
);

mat colnames tableLR = rho W WST WNST;
mat rownames tableLR = W - Wplus - WNST - WNSTplus -;

* Print Tables;
**********************************************************************************;
do writeSRmat;
do writeLRmat;

log on;
**********************************************************************************;
disp labelW;
mat li tableSR, format(%5.4f);
mat li tableLR, format(%5.3f);


**********************************************************************************;
**********************************************************************************;
* Forecasting;
**********************************************************************************;
**********************************************************************************;

* Enter counterfactual & survey forecasts;
gen dpop=400*log(pop/L.pop);
sum dpop if tin(1990Q1,2008Q4);
sca meanPopGrowth=r(mean);

* Unemployment expectations;
*****************************************;
gen unpCBOcounter = unp; gen unpCBOcounter_base = unp;
gen unpCBOcounter_counterfac1 = unp;  gen unpCBOcounter_counterfac2 = unp;
 
*replace unpCBOcounter = 8.1 if tin(2009Q1,2009Q1); 
replace unpCBOcounter = 8.6 if tin(2009Q2,2009Q2);
replace unpCBOcounter = 9.1 if tin(2009Q3,2009Q3);
replace unpCBOcounter = 9.5 if tin(2009Q4,2009Q4); * Average for 2009: 8.8;  
replace unpCBOcounter = 9.7 if tin(2010Q1,2010Q1); 
replace unpCBOcounter = 9.8 if tin(2010Q2,2010Q2);
replace unpCBOcounter = 9.3 if tin(2010Q3,2010Q3);
replace unpCBOcounter = 9.0 if tin(2010Q4,2010Q4); * Average for 2010: 9.45;
replace unpCBOcounter = 8.6 if tin(2011Q1,2011Q1);
replace unpCBOcounter = 8.3 if tin(2011Q2,2011Q2);
replace unpCBOcounter = 8.0 if tin(2011Q3,2011Q3);
replace unpCBOcounter = 7.7 if tin(2011Q4,2011Q4); * Average for 2011: 8.15;
replace unpCBOcounter = 7.4 if tin(2012Q1,2012Q1);
replace unpCBOcounter = 7.1 if tin(2012Q2,2012Q2);
replace unpCBOcounter = 6.8 if tin(2012Q3,2012Q3);
replace unpCBOcounter = 6.5 if tin(2012Q4,2012Q4); * Average for 2012: 6.95;

*replace unpCBOcounter_base = 8.1 if tin(2009Q1,2009Q1); 
replace unpCBOcounter_base = 8.3 if tin(2009Q2,2009Q2);
replace unpCBOcounter_base = 8.5 if tin(2009Q3,2009Q3);
replace unpCBOcounter_base = 8.7 if tin(2009Q4,2009Q4); * Average for 2009: 8.4;  
replace unpCBOcounter_base = 8.7 if tin(2010Q1,2010Q1); 
replace unpCBOcounter_base = 8.8 if tin(2010Q2,2010Q2);
replace unpCBOcounter_base = 8.9 if tin(2010Q3,2010Q3);
replace unpCBOcounter_base = 8.8 if tin(2010Q4,2010Q4); * Average for 2010: 8.8;
replace unpCBOcounter_base = 8.4 if tin(2011Q1,2011Q1);
replace unpCBOcounter_base = 8.0 if tin(2011Q2,2011Q2);
replace unpCBOcounter_base = 7.8 if tin(2011Q3,2011Q3);
replace unpCBOcounter_base = 7.4 if tin(2011Q4,2011Q4); * Average for 2011: 7.9;
replace unpCBOcounter_base = 7.1 if tin(2012Q1,2012Q1);
replace unpCBOcounter_base = 6.8 if tin(2012Q2,2012Q2);
replace unpCBOcounter_base = 6.6 if tin(2012Q3,2012Q3);
replace unpCBOcounter_base = 6.5 if tin(2012Q4,2012Q4); * Average for 2012: 6.75;

*replace unpCBOcounter_counterfac1 = 8.1 if tin(2009Q1,2009Q1); 
replace unpCBOcounter_counterfac1 = 8.7 if tin(2009Q2,2009Q2);
replace unpCBOcounter_counterfac1 = 9.1 if tin(2009Q3,2009Q3);
replace unpCBOcounter_counterfac1 = 9.6 if tin(2009Q4,2009Q4); * Average for 2009: 8.9;  
replace unpCBOcounter_counterfac1 = 9.9 if tin(2010Q1,2010Q1); 
replace unpCBOcounter_counterfac1 = 10.3 if tin(2010Q2,2010Q2);
replace unpCBOcounter_counterfac1 = 10.4 if tin(2010Q3,2010Q3);
replace unpCBOcounter_counterfac1 = 10.5 if tin(2010Q4,2010Q4); * Average for 2010: 10.3;
replace unpCBOcounter_counterfac1 = 9.9 if tin(2011Q1,2011Q1);
replace unpCBOcounter_counterfac1 = 9.2 if tin(2011Q2,2011Q2);
replace unpCBOcounter_counterfac1 = 8.7 if tin(2011Q3,2011Q3);
replace unpCBOcounter_counterfac1 = 8.6 if tin(2011Q4,2011Q4); * Average for 2011: 9.1;
replace unpCBOcounter_counterfac1 = 8.4 if tin(2012Q1,2012Q1);
replace unpCBOcounter_counterfac1 = 8.2 if tin(2012Q2,2012Q2);
replace unpCBOcounter_counterfac1 = 8.1 if tin(2012Q3,2012Q3);
replace unpCBOcounter_counterfac1 = 8.1 if tin(2012Q4,2012Q4); * Average for 2012: 6.75;

*replace unpCBOcounter_counterfac2 = 8.1 if tin(2009Q1,2009Q1); 
replace unpCBOcounter_counterfac2 = 7.9 if tin(2009Q2,2009Q2);
replace unpCBOcounter_counterfac2 = 7.9 if tin(2009Q3,2009Q3);
replace unpCBOcounter_counterfac2 = 7.8 if tin(2009Q4,2009Q4); * Average for 2009: 8.9;  
replace unpCBOcounter_counterfac2 = 7.5 if tin(2010Q1,2010Q1); 
replace unpCBOcounter_counterfac2 = 7.3 if tin(2010Q2,2010Q2);
replace unpCBOcounter_counterfac2 = 7.4 if tin(2010Q3,2010Q3);
replace unpCBOcounter_counterfac2 = 7.1 if tin(2010Q4,2010Q4); * Average for 2010: 10.3;
replace unpCBOcounter_counterfac2 = 6.9 if tin(2011Q1,2011Q1);
replace unpCBOcounter_counterfac2 = 6.8 if tin(2011Q2,2011Q2);
replace unpCBOcounter_counterfac2 = 6.9 if tin(2011Q3,2011Q3);
replace unpCBOcounter_counterfac2 = 6.2 if tin(2011Q4,2011Q4); * Average for 2011: 9.1;
replace unpCBOcounter_counterfac2 = 5.8 if tin(2012Q1,2012Q1);
replace unpCBOcounter_counterfac2 = 5.4 if tin(2012Q2,2012Q2);
replace unpCBOcounter_counterfac2 = 5.1 if tin(2012Q3,2012Q3);
replace unpCBOcounter_counterfac2 = 4.9 if tin(2012Q4,2012Q4); * Average for 2012: 6.75;

gen aveUnpCBOcounter_base = .25*(L4.unpCBOcounter_base+L3.unpCBOcounter_base+L2.unpCBOcounter_base+L1.unpCBOcounter_base);
gen daveUnpCBOcounter_base = F4.aveUnpCBOcounter_base-aveUnpCBOcounter_base;

gen aveUnpCBOcounter_counterfac1 = .25*(L4.unpCBOcounter_counterfac1+L3.unpCBOcounter_counterfac1+L2.unpCBOcounter_counterfac1+L1.unpCBOcounter_counterfac1);
gen daveUnpCBOcounter_counterfac1 = F4.aveUnpCBOcounter_counterfac1-aveUnpCBOcounter_counterfac1;

gen aveUnpCBOcounter_counterfac2 = .25*(L4.unpCBOcounter_counterfac2+L3.unpCBOcounter_counterfac2+L2.unpCBOcounter_counterfac2+L1.unpCBOcounter_counterfac2);
gen daveUnpCBOcounter_counterfac2 = F4.aveUnpCBOcounter_counterfac2-aveUnpCBOcounter_counterfac2;

* Income; 
**********************************************************************************;
gen dydisp_cf = dydisp;
* approximate income growth with GDP expectations from Consensus (in per capita terms);
*replace dydisp_cf = -1.4*4-meanPopGrowth if tin(2009Q1,2009Q1);
replace dydisp_cf = -0.6*4-meanPopGrowth if tin(2009Q2,2009Q2);
replace dydisp_cf = 0.1*4-meanPopGrowth if tin(2009Q3,2009Q3);
replace dydisp_cf = 0.4*4-meanPopGrowth if tin(2009Q4,2009Q4); * Average for 2009: 8.8; 
replace dydisp_cf = 0.5*4-meanPopGrowth if tin(2010Q1,2010Q1);
replace dydisp_cf = 0.6*4-meanPopGrowth if tin(2010Q2,2010Q2);
replace dydisp_cf = 0.7*4-meanPopGrowth if tin(2010Q3,2010Q3);
replace dydisp_cf = 0.7*4-meanPopGrowth if tin(2010Q4,2010Q4);
replace dydisp_cf = 3.0-meanPopGrowth if tin(2011Q1,2011Q1); * LT forecasts from april report 3.5% in 2011;
replace dydisp_cf = 3.4-meanPopGrowth if tin(2011Q2,2011Q2);
replace dydisp_cf = 3.8-meanPopGrowth if tin(2011Q3,2011Q3);
replace dydisp_cf = 4.0-meanPopGrowth if tin(2011Q4,2011Q4);
replace dydisp_cf = 3.7-meanPopGrowth if tin(2012Q1,2012Q4); * LT forecasts from april report 3.7% in 2011;

gen dydisp_cf_base = dydisp_cf;
gen dydisp_cf_counterfac1 = dydisp_cf;	
gen dydisp_cf_counterfac2 = dydisp_cf;	

if $cfIncomeIndex==2 {; 

	* These are the baseline stress test interpolated figures (Note: these are already in per capita terms);
	*replace dydisp_cf_base = -3.4 if tin(2009Q1,2009Q1);
	replace dydisp_cf_base = -3.1 if tin(2009Q2,2009Q2);
	replace dydisp_cf_base = -2.4 if tin(2009Q3,2009Q3);
	replace dydisp_cf_base = -2.1 if tin(2009Q4,2009Q4); 
	replace dydisp_cf_base = -1.1 if tin(2010Q1,2010Q1);
	replace dydisp_cf_base = 0 if tin(2010Q2,2010Q2);
	replace dydisp_cf_base = 1.1 if tin(2010Q3,2010Q3);
	replace dydisp_cf_base = 1.9 if tin(2010Q4,2010Q4);
	replace dydisp_cf_base = 2.1 if tin(2011Q1,2011Q1); 
	replace dydisp_cf_base = 2.3 if tin(2011Q2,2011Q2);
	replace dydisp_cf_base = 2.4 if tin(2011Q3,2011Q3);
	replace dydisp_cf_base = 2.5 if tin(2011Q4,2011Q4);
	replace dydisp_cf_base = 2.6 if tin(2012Q1,2012Q2);  
	replace dydisp_cf_base = 2.7 if tin(2012Q3,2012Q4); 

	* PESSIMISTIC;
	*replace dydisp_cf_counterfac1 = -5.6 if tin(2009Q1,2009Q1);
	replace dydisp_cf_counterfac1 = -4.4 if tin(2009Q2,2009Q2);
	replace dydisp_cf_counterfac1 = -4.0 if tin(2009Q3,2009Q3);
	replace dydisp_cf_counterfac1 = -3.5 if tin(2009Q4,2009Q4); 
	replace dydisp_cf_counterfac1 = -2.2 if tin(2010Q1,2010Q1);
	replace dydisp_cf_counterfac1 = -1.1 if tin(2010Q2,2010Q2);
	replace dydisp_cf_counterfac1 = -0.6 if tin(2010Q3,2010Q3);
	replace dydisp_cf_counterfac1 = 0.0 if tin(2010Q4,2010Q4);
	replace dydisp_cf_counterfac1 = 1.1 if tin(2011Q1,2011Q1); 
	replace dydisp_cf_counterfac1 = 2.0 if tin(2011Q2,2011Q2);
	replace dydisp_cf_counterfac1 = 2.4 if tin(2011Q3,2011Q3);
	replace dydisp_cf_counterfac1 = 2.5 if tin(2011Q4,2011Q4);
	replace dydisp_cf_counterfac1 = 2.6 if tin(2012Q1,2012Q2);  
	replace dydisp_cf_counterfac1 = 2.7 if tin(2012Q3,2012Q4); 

	* OPTIMISTIC;
	*replace dydisp_cf_counterfac2 = -3.1 if tin(2009Q1,2009Q1);
	replace dydisp_cf_counterfac2 = -2.4 if tin(2009Q2,2009Q2);
	replace dydisp_cf_counterfac2 = -2.1 if tin(2009Q3,2009Q3);
	replace dydisp_cf_counterfac2 = -1.1 if tin(2009Q4,2009Q4); 
	replace dydisp_cf_counterfac2 = 1.1 if tin(2010Q1,2010Q1);
	replace dydisp_cf_counterfac2 = 1.9 if tin(2010Q2,2010Q2);
	replace dydisp_cf_counterfac2 = 2.3 if tin(2010Q3,2010Q3);
	replace dydisp_cf_counterfac2 = 2.8 if tin(2010Q4,2010Q4);
	replace dydisp_cf_counterfac2 = 2.9 if tin(2011Q1,2011Q1); 
	replace dydisp_cf_counterfac2 = 3.0 if tin(2011Q2,2011Q2);
	replace dydisp_cf_counterfac2 = 3.0 if tin(2011Q3,2011Q3);
	replace dydisp_cf_counterfac2 = 3.0 if tin(2011Q4,2011Q4);
	replace dydisp_cf_counterfac2 = 2.9 if tin(2012Q1,2012Q2);  
	replace dydisp_cf_counterfac2 = 2.9 if tin(2012Q3,2012Q4); 

	*replace dydisp_cf_counterfac1 = dydisp_cf_base;
	*replace dydisp_cf_counterfac2 = dydisp_cf_base;
	
};

* Consumption; 
**********************************************************************************;
gen tconsCF = tcons;
gen dtconsCF = dtcons;
*replace dtconsCF = -0.3*4-meanPopGrowth if tin(2009Q1,2009Q1); * in annualized per capita terms (march 09 CF data);
replace dtconsCF = -0.1*4-meanPopGrowth if tin(2009Q2,2009Q2);
replace dtconsCF = 0.2*4-meanPopGrowth if tin(2009Q3,2009Q3);
replace dtconsCF = 0.3*4-meanPopGrowth if tin(2009Q4,2009Q4);
replace dtconsCF = 0.5*4-meanPopGrowth if tin(2010Q1,2010Q1);
replace dtconsCF = 0.6*4-meanPopGrowth if tin(2010Q2,2010Q2);
replace dtconsCF = 0.7*4-meanPopGrowth if tin(2010Q3,2010Q3);
replace dtconsCF = 0.7*4-meanPopGrowth if tin(2010Q4,2010Q4);
replace dtconsCF = 2.8-meanPopGrowth if tin(2011Q1,2011Q1); * from here long-term forecasts, april 09 CF;
replace dtconsCF = 2.8-meanPopGrowth if tin(2011Q2,2011Q2);
replace dtconsCF = 2.8-meanPopGrowth if tin(2011Q3,2011Q3);
replace dtconsCF = 2.8-meanPopGrowth if tin(2011Q4,2011Q4);
replace dtconsCF = 3.1-meanPopGrowth if tin(2012Q1,2012Q4);

forvalues i = $startForeNum(1)$endForeNum {;

	sca tconsCFAux = tconsCF[`i'-1]*(1+dtconsCF[`i']/400);
	replace tconsCF = tconsCFAux in `i';

};

* Generate sentiment (MUExp) path;
**************************************;
gen MUExp_sent_base=.; gen MUExp_sent_counterfac1=.; gen MUExp_sent_counterfac2=.;
gen aveUnp= 0.25*(L.unp+L2.unp+L3.unp+L4.unp);
gen daveUnp = F4.aveUnp-aveUnp;

reg MUExp daveUnp L.MUExp if tin($startRegW,$endRegW);
sca MUExpConstCoeff = _b[_cons];
sca MUExpDunCoeff = _b[daveUnp];
sca MUExpLMUECoeff = _b[L.MUExp];

replace MUExp_sent_base=MUExp;
replace MUExp_sent_counterfac1=MUExp;
replace MUExp_sent_counterfac2=MUExp;

local allScen "base counterfac1 counterfac2";

foreach scen of local allScen {;
	forvalues i = $startForeNum(1)$endForeNum {;

		sca MUExp_Aux_`scen' = MUExpConstCoeff+MUExpDunCoeff*daveUnpCBOcounter_`scen'[`i']+MUExpLMUECoeff*MUExp_sent_`scen'[`i'-1];
		replace MUExp_sent_`scen' = MUExp_Aux_`scen' in `i';

	};
};

if $fixSentIndex==2 {;
	replace MUExp_sent_counterfac1=MUExp_sent_base;
	replace MUExp_sent_counterfac2=MUExp_sent_base;
};	

* Set up baseline + other scenarios;
* Baseline;
**************************************;

gen lrlincome = log(rlincome);
gen dlrlincome = 400*log(rlincome/L.rlincome);
gen dlwealth = 400*log(wealth/L.wealth);
gen dlwthstock = 400*log(wthstock/L.wthstock);
gen dlwthnonstock = 400*log(wthnonstock/L.wthnonstock);

* Extend normalization variable (tcons);
gen dnormVar = log($normVar)-log(L.$normVar);
sum dnormVar if tin($startRegW,$endRegW);
sca meanDnormVar = r(mean);

gen normVarFore = $normVar;

replace normVarFore = normVarFore[q($startFore)-q(1947q1)]*(1+meanDnormVar)^(_n-(q($startFore)-q(1947q1))) if tin($startFore,$endFore);    
* 245 = 2008Q1;

* Extend control variables with last figures (assumes RW);
sum MUExp if tin($startRegW,$endRegW);
sca meanMUExp = r(mean);

*replace MUExp = MUExp[244] in 245;
replace MUExp = MUExp[q($startFore)-q(1947q1)] if tin($startFore,$endFore); ***************** Note that sentiment wasn't available, so the period had to be shifted;
*replace MUExp = meanMUExp if tin(2009Q1,$endFore);

gen MUExp_base=MUExp;
gen MUExp_counterfac1=MUExp;
gen MUExp_counterfac2=MUExp;

if $sentScenario==2 {;
	replace MUExp_base=MUExp_sent_base if tin(2009Q1,$endFore);
	replace MUExp_counterfac1=MUExp_sent_counterfac1 if tin(2009Q1,$endFore);
	replace MUExp_counterfac2=MUExp_sent_counterfac1 if tin(2009Q1,$endFore);
};

* March 2009 CF expectations of 3MTB/1000;
replace fedfunds = 0.0003 if tin(2009Q2,2009Q2); 
replace fedfunds = 0.0003 if tin(2009Q3,2009Q3); 
replace fedfunds = 0.0004 if tin(2009Q4,2009Q4); 
replace fedfunds = 0.0006 if tin(2010Q1,2010Q1); 
replace fedfunds = 0.0007 if tin(2010Q2,2010Q2); 
replace fedfunds = 0.0009 if tin(2010Q3,2010Q3); 
replace fedfunds = 0.0012 if tin(2010Q4,2012Q4); 

* Impose future path for wealth (and its components);
sum dlwealth if tin($startRegW,$endRegW);
sca meanDLWealth = r(mean);

sum dlwthstock if tin($startRegW,$endRegW);
sca meanDLWthstock = r(mean);

sum dlwthnonstock if tin($startRegW,$endRegW);
sca meanDLWthnonstock = r(mean);

global startForeNum = q($startFore)-q(1947q1)+1;
global endForeNum = q($endFore)-q(1947q1)+1;

sca houseNWrat = restate[248]/networth[248];
sca houseNstockRat = restate[248]/wnstock[248];
gen exponentSeries=.;
gen counterSeries=_n;

replace exponentSeries=counterSeries-248 if tin($startForeM1,$endFore);

* Baseline parameters;
***************************************************************************;

sca qHouseFall_base_1_rate=-0.14-meanPopGrowth/100-(-0.007); * Approx for real per capita growth of house wealth in 09 (infl -0.7) under baseline scenario;
sca qHouseFall_base_2_rate=-0.04-meanPopGrowth/100-(0.016); * Approx for real per capita growth of house wealth in 09 (infl -0.7) under baseline scenario;

sca qHouseFall_base_1=1-((1+qHouseFall_base_1_rate)^.25);
sca qHouseFall_base_2=1-((1+qHouseFall_base_2_rate)^.25);

* Counterfactual 1 (pessimistic);
sca qHouseFall_counterfac1_1_rate=-0.22-meanPopGrowth/100-(-0.007); * Approx for real per capita growth of house wealth in 09 (infl -0.7) under baseline scenario;
sca qHouseFall_counterfac1_2_rate=-0.07-meanPopGrowth/100-(0.016); * Approx for real per capita growth of house wealth in 09 (infl -0.7) under baseline scenario;

sca qHouseFall_counterfac1_1=1-((1+qHouseFall_counterfac1_1_rate)^.25);
sca qHouseFall_counterfac1_2=1-((1+qHouseFall_counterfac1_2_rate)^.25);

* Counterfactual 2 (optimistic);
sca qHouseFall_counterfac2_1_rate=-0.06-meanPopGrowth/100-(-0.007); * Approx for real per capita growth of house wealth in 09 (infl -0.7) under baseline scenario;
sca qHouseFall_counterfac2_2_rate=-0.01-meanPopGrowth/100-(0.016); * Approx for real per capita growth of house wealth in 09 (infl -0.7) under baseline scenario;

sca qHouseFall_counterfac2_1=1-((1+qHouseFall_counterfac2_1_rate)^.25);
sca qHouseFall_counterfac2_2=1-((1+qHouseFall_counterfac2_2_rate)^.25);

* Impose future path for wealth (and its components);
sum dlwealth if tin($startRegW,$endRegW);
sca meanDLWealth = r(mean)/400; * Assume inflation of 2.2;

sum dlwthstock if tin($startRegW,$endRegW);
sca meanDLWthstock = r(mean)/400;

sum dlwthnonstock if tin($startRegW,$endRegW);
sca meanDLWthnonstock = r(mean)/400;

local allScen "base counterfac1 counterfac2";

foreach scen of local allScen {;

	gen wealth_`scen' = wealth; gen wealthSt_`scen' = wthstock; gen wealthNst_`scen' = wthnonstock;
	gen tconsWPlus_`scen' = tcons; gen tconsSNPlus_`scen' = tcons;

	* Generate counterfactual wealth series;
	**************************************;
	replace wealth_`scen' = wealth[q($startFore)-q(1947q1)-1]*(1-qHouseFall_`scen'_1*houseNWrat)^exponentSeries if tin($startForeM1,2009Q4);	   * adjust for the fraction of housing on net worth (houseNWrat);  
	replace wealth_`scen' = wealth_`scen'[q(2010Q1)-q(1947q1)]*(1-qHouseFall_`scen'_2*houseNWrat)^(exponentSeries-4) if tin(2010Q1,2010Q4);	

	replace wealthSt_`scen' = wthstock[q($startFore)-q(1947q1)-1] if tin($startForeM1,$endFore);

	replace wealthNst_`scen' = wthnonstock[q($startFore)-q(1947q1)-1]*(1-qHouseFall_`scen'_1*houseNstockRat)^exponentSeries if tin($startForeM1,2009Q4);    * adjust for the fraction of housing on nonstock wealth (houseNstockRat); 
	replace wealthNst_`scen' = wealthNst_`scen'[q(2010Q1)-q(1947q1)]*(1-qHouseFall_`scen'_2*houseNstockRat)^(exponentSeries-4) if tin(2010Q1,2010Q4);

	replace wealth_`scen' = wealth_`scen'[q(2011Q1)-q(1947q1)]*(1+meanDLWealth)^(exponentSeries-8)  if tin(2011Q1,$endFore);
	replace wealthNst_`scen' = wealthNst_`scen'[q(2011Q1)-q(1947q1)]*(1+meanDLWthnonstock)^(exponentSeries-8) if tin(2011Q1,$endFore);

	* Back out the implied consumption;
	**************************************;
	gen dwdel4GeomWPlus_`scen' = (D.wealth_`scen'+decayPlus*LD.wealth_`scen' +(decayPlus^2)*L2D.wealth_`scen' + (decayPlus^3)*L3D.wealth_`scen')/L4.normVarFore;
	
	gen dwstdel4GeomSNPlus_`scen' = (D.wealthSt_`scen'+decaySandNPlus*LD.wealthSt_`scen' +(decaySandNPlus^2)*L2D.wealthSt_`scen' + (decaySandNPlus^3)*L3D.wealthSt_`scen')/L4.normVarFore;
	
	gen dwnstdel4GeomSNPlus_`scen' = (D.wealthNst_`scen'+decaySandNPlus*LD.wealthNst_`scen' +(decaySandNPlus^2)*L2D.wealthNst_`scen' + (decaySandNPlus^3)*L3D.wealthNst_`scen')/L4.normVarFore;
	
	gen cdelPredWPlus_`scen' = bWPlusConst + bdwdel4GeomPlus*L.dwdel4GeomWPlus_`scen' + bWPlusMich*L.MUExp_`scen'+bWPlusFF*L.fedfunds;
	
	gen cdelPredSNPlus_`scen' = bSNPlusConst + bdwstdel4GeomSNPlus*L.dwstdel4GeomSNPlus_`scen' + bdwnstdel4GeomSNPlus*L.dwnstdel4GeomSNPlus_`scen' + bSNPlusMich*L.MUExp_`scen'+bSNPlusFF*L.fedfunds;
	
	* Back out C from cdel;
	**************************************;	
	forvalues i = $startForeNum(1)$endForeNum {;
		sca tconsAuxWPlus = tconsWPlus_`scen'[`i'-1]+cdelPredWPlus_`scen'[`i']*tconsWPlus_`scen'[`i'-5];
		replace tconsWPlus_`scen' = tconsAuxWPlus in `i';
	
		sca tconsAuxSNPlus = tconsSNPlus_`scen'[`i'-1]+cdelPredSNPlus_`scen'[`i']*tconsSNPlus_`scen'[`i'-5];
		replace tconsSNPlus_`scen' = tconsAuxSNPlus in `i';
	
	};
	
	gen dtconsWPlus_`scen'=400*log(tconsWPlus_`scen'/L.tconsWPlus_`scen');
	gen dtconsSNPlus_`scen'=400*log(tconsSNPlus_`scen'/L.tconsSNPlus_`scen');	

};

**************************************;
* Figures;
**************************************;
global endOfSample = q($startFore)-1;
global endGraph "2011Q4";

cd $basePath\figures;
global endOfSample = q($startFore)-1;
global textXcoord = $endOfSample+4;
global textXcoordS=$textXcoord+2;

* Wealth;
graph twoway 
(line wealth_base t if tin(2006Q1,$endGraph), xline($endOfSample) text(200 $textXcoord "Forecasting period") clwidth(medthick) lcolor(red) ytitle("Year 2000 thousand dollars")) 
(line wealth_counterfac1 t if tin(2006Q1,$endGraph), clwidth(medthick) lcolor(black)) 
(line wealth_counterfac2 t if tin(2006Q1,$endGraph), xlabel(188(4)206,format(%tqCY)) clwidth(medthin) lcolor(black)) 
(line wealthNst_base t if tin(2006Q1,$endGraph), clwidth(medthick) lpattern(-) lcolor(red)) 
(line wealthNst_counterfac1 t if tin(2006Q1,$endGraph), clwidth(medthick) lpattern(-) lcolor(black))
(line wealthNst_counterfac2 t if tin(2006Q1,$endGraph), clwidth(medthin) lpattern(-) lcolor(black))  
(line wealthSt_base t if tin(2006Q1,$endGraph), clwidth(medthick) lpattern(-.) lcolor(red) legend(cols(3) lab(1 "Tot W Base") lab(2 "Tot W Sim 1 (Pess)") lab(3 "Tot W Sim 2 (Opt)") lab(4 "HW Base") lab(5 "HW Sim 1 (Pess)") lab(6 "HW Sim 2 (Opt)") lab(7 "NHW All") )), name(wealthCounterF);

graph save wealthCounterF wealthCounterF, asis replace;
graph export wealthCounterF.eps, replace;

* Consumption;
graph twoway (line tconsWPlus_base t if tin($startForeM1,$endGraph), xline($endOfSample) text(27.5 $textXcoord "Forecasting period") ytitle("") ytitle("Year 2000 thousand dollars") clwidth(medthick) lcolor(red)) 
(line tconsWPlus_counterfac1 t if tin(2006Q1,$endGraph), clwidth(medthick) lcolor(black)) 
(line tconsWPlus_counterfac2 t if tin($startForeM1,$endGraph), clwidth(medthin) lcolor(black)) 
(line tconsSNPlus_base  t if tin($startForeM1,$endGraph), clwidth(medthick) lcolor(red) lpattern(-)) 
(line tconsSNPlus_counterfac1 t if tin($startForeM1,$endGraph), clwidth(medthick) lpattern(-) lcolor(black))  
(line tconsSNPlus_counterfac2 t if tin($startForeM1,$endGraph), xlabel(188(4)206,format(%tqCY)) lpattern(-) clwidth(medthin) lcolor(black))
(line tconsCF t if tin($startForeM1,$endGraph), xlabel(188(4)206,format(%tqCY)) clwidth(medthin) lcolor(blue) 
legend(cols(3) lab(1 "Tot W Base") lab(2 "Tot W Sim 1 (Pess)") lab(3 "Tot W Sim 2 (Opt)") lab(4 "H&NH W Base") lab(5 "H&NH W Sim 1 (Pess)") lab(6 "H&NH W Sim 2 (Opt)") lab(7 "CF"))), name(cCounterF);

graph save cCounterF cCounterF, asis replace;
graph export cCounterF.eps, replace;

*************************************************************************************************************;
cd $logPath;

**************************************;
* Predict disposable income;
**************************************;

arima dydisp if tin($startRegW,$endRegW), ar(1) ma(1); 
predict dydisp_arma;


gen ydispCounterArma = ydisp;
gen ydispCounterCf = ydisp;

reg dydisp L(1/4).dtcons L(1/4).MUExp L(1/4).unp if tin($startRegW,$endRegW);

reg dydisp L(1/4).dtcons L(1/4).MUExp if tin($startRegW,$endRegW);
sca bDyDcL1 = _b[L.dtcons];
sca bDyDcL2 = _b[L2.dtcons];
sca bDyDcL3 = _b[L3.dtcons];
sca bDyDcL4 = _b[L4.dtcons];
sca bDyDicsL1 = _b[L.MUExp];
sca bDyDicsL2 = _b[L2.MUExp];
sca bDyDicsL3 = _b[L3.MUExp];
sca bDyDicsL4 = _b[L4.MUExp];
sca bDyConst = _b[_cons];

* Extend income level with expected growth rates;
**************************************************************************;
gen ydispCounterCf_base = ydisp; gen ydispCounterCf_counterfac1 = ydisp; gen ydispCounterCf_counterfac2 = ydisp;


forvalues i = $startForeNum(1)$endForeNum {;

	sca ydispAuxArma = ydispCounterArma[`i'-1]*(1+dydisp_arma[`i']/400);
	replace ydispCounterArma = ydispAuxArma in `i';

	sca ydispAuxCf = ydispCounterCf[`i'-1]*(1+dydisp_cf[`i']/400);
	replace ydispCounterCf = ydispAuxCf in `i';
	
	foreach scen of local allScen {;

		sca ydispAuxCf = ydispCounterCf_`scen'[`i'-1]*(1+dydisp_cf_`scen'[`i']/400);
		replace ydispCounterCf_`scen' = ydispAuxCf in `i';

	};

};

* Given Y and C forecasts back out savings rates;
**************************************************************************;
cd $basePath\figures;

* Note that the BEA defines personal saving rate as personal saving/disposable income, where personal saving = (income-PCE-personal interest rate payments-personal current transfer payments).  For the latter two items we make an ad hoc assumption that they will make up the same fraction of income as the did in 2008.;
gen sRateBea = 100*persave/disposy; * both nominal here!;
gen sRateMyTemp = 100*(ydisp-tcons)/ydisp;
gen sRateDiff = sRateBea-sRateMyTemp;

sum sRateDiff if tin(2008Q1,2008Q4);
sca sRateAdjust = r(mean);  * sRateAdjust is negative;
gen zero=0;

gen sRateSNbaseYarma = sRateBea; gen sRateSNbaseYcf = sRateBea;
gen sRateSNcounterfac1Yarma = sRateBea; gen sRateSNcounterfac1Ycf = sRateBea;
gen sRateSNcounterfac2Yarma = sRateBea; gen sRateSNcounterfac2Ycf = sRateBea;
gen sRateWbaseYarma = sRateBea; gen sRateWbaseYcf = sRateBea;
gen sRateWcounterfac1Yarma = sRateBea; gen sRateWcounterfac1Ycf = sRateBea;
gen sRateWcounterfac2Yarma = sRateBea; gen sRateWcounterfac2Ycf = sRateBea;
gen sRateCF=sRateBea;

replace sRateSNbaseYcf = 100*(ydispCounterCf_base-tconsSNPlus_base)/ydispCounterCf_base+sRateAdjust if tin($startFore,$endFore);
replace sRateSNcounterfac1Ycf = 100*(ydispCounterCf_counterfac1-tconsSNPlus_counterfac1)/ydispCounterCf_counterfac1+sRateAdjust if tin($startFore,$endFore);
replace sRateSNcounterfac2Ycf = 100*(ydispCounterCf_counterfac2-tconsSNPlus_counterfac2)/ydispCounterCf_counterfac2+sRateAdjust if tin($startFore,$endFore);
replace sRateWbaseYcf = 100*(ydispCounterCf_base-tconsWPlus_base)/ydispCounterCf_base+sRateAdjust if tin($startFore,$endFore);
replace sRateWcounterfac1Ycf = 100*(ydispCounterCf_counterfac1-tconsWPlus_counterfac1)/ydispCounterCf_counterfac1+sRateAdjust if tin($startFore,$endFore);
replace sRateWcounterfac2Ycf = 100*(ydispCounterCf_counterfac2-tconsWPlus_counterfac2)/ydispCounterCf_counterfac2+sRateAdjust if tin($startFore,$endFore);
replace sRateCF = 100*(ydispCounterCf-tconsCF)/ydispCounterCf+sRateAdjust if tin($startFore,$endFore);

*line sRateSNbaseYcf sRateSNcounterfac1Ycf sRateSNcounterfac2Ycf sRateWbaseYcf  sRateWcounterfac1Ycf  sRateWcounterfac2Ycf sRateCF t if tin(1995Q2,2011Q4), xline($endOfSample) yline(0, lcolor(black)) legend(cols(3) lab(1 "NHW Base") lab(2 "NHW S1") lab(3 "NHW S2") lab(4 "TW Base") lab(5 "TW S1") lab(6 "TW S2") lab(7 "CF")) xlabel(144(8)208,format(%tqCY)) name(sRateSelected);


graph twoway 
(line sRateWbaseYcf t if tin($startForeM1,$endGraph), xline($endOfSample) text(200 $textXcoord "Forecasting period") clwidth(medthick) lcolor(red) ytitle("Year 2000 thousand dollars")) 
(line sRateWcounterfac1Ycf t if tin(1995Q1,$endGraph), clwidth(medthick) lcolor(black)) 
(line sRateWcounterfac2Ycf t if tin($startForeM1,$endGraph), xlabel(140(8)206,format(%tqCY)) clwidth(medthin) lcolor(black)) 
(line sRateSNbaseYcf t if tin($startForeM1,$endGraph), clwidth(medthick) lpattern(-) lcolor(red)) 
(line sRateSNcounterfac1Ycf t if tin($startForeM1,$endGraph), clwidth(medthick) lpattern(-) lcolor(black))
(line sRateSNcounterfac2Ycf t if tin($startForeM1,$endGraph), clwidth(medthin) lpattern(-) lcolor(black))  
(line sRateCF t if tin($startForeM1,$endGraph), clwidth(medthick) lcolor(blue))
(line zero t if tin(1995Q1,$endGraph), clwidth(medthin) lcolor(black)
legend(order (1 2 3 4 5 6 7) cols(3) lab(1 "Tot W Base") lab(2 "Tot W Sim 1 (Pess)") lab(3 "Tot W Sim 2 (Opt)") lab(4 "HW Base") lab(5 "HW Sim 1 (Pess)") lab(6 "HW Sim 2 (Opt)") lab(7 "CF"))), name(sRateSelected);

*line sRateSNbaseYcf sRateSNcounterfac1Ycf sRateSNcounterfac2Ycf sRateWbaseYcf  sRateWcounterfac1Ycf  sRateWcounterfac2Ycf sRateCF t if tin(1995Q2,2011Q4), xline($endOfSample) yline(0, lcolor(black)) legend(cols(3) lab(1 "NHW Base CF") lab(2 "NHW S1 CF") lab(3 "NHW S2 CF") lab(4 "TW Base CF") lab(5 "TW S1 CF") lab(6 "TW S2 CF") lab(7 "CF CF")) xlabel(160(8)204,format(%tqCY)) name(sRateSelected);

graph save sRateSelected sRateSelected, asis replace;
graph export sRateSelected.eps, replace;

**************************************************************************;

set scheme s1mono;

/*
graph twoway (line dydisp t if tin(2000Q1,$endRegW), xline($endOfSample) text(10 $textXcoordS "Forecasting period") ytitle("") clwidth(medthick) lcolor(black) xlabel(160(4)208,format(%tqCY))) 
(line dydisp_cf t if tin($endRegW,$endFore), clwidth(medthick) lcolor(red)
legend(order(2) lab(2 "CF Forecast"))), name(fDinc);

*legend(order(2 3) lab(2 "ARMA(1,1) Forecast") lab(3 "CF Forecast"))), name(fDinc);
*(line dydisp_arma t if tin($endRegW,$endFore), clwidth(medthick) lcolor(red) lpattern(-));

graph save fDinc fDinc, asis replace;
graph export fDinc.eps, replace;
*/;

graph twoway (line ydisp t if tin(2000Q1,$startForeM1), xline($endOfSample) text(32 $textXcoordS "Forecasting period") ytitle("") clwidth(medthick) lcolor(black) xlabel(160(4)208,format(%tqCY))) 
(line ydispCounterCf t if tin($startForeM1,$endFore), clwidth(medthick) lcolor(red)
legend(order(2) lab(2 "CF Forecast"))), name(fInc); 

*(line ydispCounterArma t if tin($endRegW,$endFore), clwidth(medthick) lcolor(red) lpattern(-))
(line ydispCounterCf t if tin($endRegW,$endFore), clwidth(medthick) lcolor(red)
legend(order(2 3) lab(2 "ARMA(1,1) Forecast") lab(3 "CF Forecast"))), name(fInc);

graph save fInc fInc, asis replace;
graph export fInc.eps, replace;

* Sentiment;
gen MUExp_estSample=.; replace MUExp_estSample=MUExp if tin($startRegW,$endRegW);
gen MUExp_foreSample_base=.; replace MUExp_foreSample_base=MUExp_sent_base if tin(2008Q4,$endFore);
gen MUExp_foreSample_counterfac1=.; replace MUExp_foreSample_counterfac1=MUExp_sent_counterfac1 if tin(2008Q4,$endFore);
gen MUExp_foreSample_counterfac2=.; replace MUExp_foreSample_counterfac2=MUExp_sent_counterfac2 if tin(2008Q4,$endFore);

graph twoway (line MUExp t if tin(2000Q1,$startForeM1), xline($endOfSample) text(32 $textXcoordS "Forecasting period") ytitle("") clwidth(medthick) lcolor(black) xlabel(160(4)208,format(%tqCY))) 
(line MUExp_foreSample_base t if tin($startForeM1,$endFore), clwidth(medthick) lcolor(red))
(line MUExp_foreSample_counterfac1 t if tin($startForeM1,$endFore), clwidth(medthick) lpattern(-) lcolor(red))
(line MUExp_foreSample_counterfac2 t if tin($startForeM1,$endFore), clwidth(medthick) lpattern(-.) lcolor(red)
legend(order(2 3 4) lab(2 "MUExp Base") lab(3 "MUExp Pess (c'fac 1)") lab(4 "MUExp Opt (c'fac 2)"))), name(fSent);

graph save fSent fSent, asis replace;
graph export fSent.eps, replace;

**********************************************************************************;
log close;	
